About
========

AlgorumQuantClient helps you build your Algo Trading strategy for Algorum Cloud.

Installation
------------

Install AlgorumQuantClient by running:

    install algorum-quant-client-py3

Documentation
-------------

You can find the detailed documentation on using AlgorumQuantClient package at below URL:

    https://docs.algorumsoftware.com/

License
-------

The project is licensed under the MIT license.